pub struct ROS2Plugin;Trait Implementations
Sourceimpl Plugin for ROS2Plugin
impl Plugin for ROS2Plugin
Sourceconst PLUGIN_VERSION: &'static str = "1.7.2"
const PLUGIN_VERSION: &'static str = "1.7.2"
Plugin’s version. Used only for information purposes. It’s recommended to use plugin_version! macro to generate this string.
Sourceconst PLUGIN_LONG_VERSION: &'static str = "v1.7.2"
const PLUGIN_LONG_VERSION: &'static str = "v1.7.2"
Plugin’s long version (with git commit hash). Used only for information purposes. It’s recommended to use plugin_version! macro to generate this string.
Sourceconst DEFAULT_NAME: &'static str = "ros2dds"
const DEFAULT_NAME: &'static str = "ros2dds"
Plugins’ default name when statically linked.
type StartArgs = DynamicRuntime
type Instance = Box<dyn RunningPluginTrait + Sync + Send>
Sourceimpl PluginControl for ROS2Plugin
impl PluginControl for ROS2Plugin
Sourcefn report(&self) -> PluginReport
fn report(&self) -> PluginReport
Returns the current state of the running plugin. By default, the state is
PluginReportLevel::Normal and the list of messages is empty.
This can be overridden by the plugin implementation if the plugin is able to report its status: no connection to the database, etc.Sourcefn plugins_status(&self, _names: &keyexpr) -> Vec<PluginStatusRec<'_>>
fn plugins_status(&self, _names: &keyexpr) -> Vec<PluginStatusRec<'_>>
Collects information of sub-plugins matching the
_names key expression. The information is richer than the one returned by report(): it contains external information about the running plugin, such as its name, path on disk, load status, etc.
Returns an empty list by default.Sourceimpl RunningPluginTrait for ROS2Plugin
impl RunningPluginTrait for ROS2Plugin
Sourcefn config_checker(
&self,
_path: &str,
_current: &JsonKeyValueMap,
_new: &JsonKeyValueMap,
) -> Result<Option<JsonKeyValueMap>, Box<dyn Error + Sync + Send>>
fn config_checker( &self, _path: &str, _current: &JsonKeyValueMap, _new: &JsonKeyValueMap, ) -> Result<Option<JsonKeyValueMap>, Box<dyn Error + Sync + Send>>
Function that will be called when the configuration relevant to the plugin is about to change. Read more
Sourcefn adminspace_getter<'a>(
&'a self,
_key_expr: &'a KeyExpr<'a>,
_plugin_status_key: &str,
) -> Result<Vec<Response>, Box<dyn Error + Sync + Send>>
fn adminspace_getter<'a>( &'a self, _key_expr: &'a KeyExpr<'a>, _plugin_status_key: &str, ) -> Result<Vec<Response>, Box<dyn Error + Sync + Send>>
Used to request the plugin’s status for the administration space.
Function called on any query on the admin space that matches this plugin’s sub-part of the admin space.
Thus the plugin can reply with its contribution to the global admin space of this zenohd.
Parameters: Read more
impl ZenohPlugin for ROS2Plugin